@@ -1,9 +1,11 @@
 # flake8: noqa: E501
 import logging
+import traceback
 from os import unlink
 from pathlib import Path
 from secrets import token_bytes
 from shutil import copy, move
+import time
 
 import pytest
 from blspy import AugSchemeMPL
@@ -27,7 +29,7 @@ from salvia.util.hash import std_hash
 from salvia.util.ints import uint8, uint16, uint32, uint64
 from salvia.wallet.derive_keys import master_sk_to_wallet_sk, master_sk_to_pooling_authentication_sk
 from tests.setup_nodes import bt, self_hostname, setup_farmer_harvester, test_constants
-from tests.time_out_assert import time_out_assert
+from tests.time_out_assert import time_out_assert, time_out_assert_custom_interval
 
 log = logging.getLogger(__name__)
 
@@ -169,37 +171,66 @@ class TestRpc:
             res_2 = await client_2.get_plots()
             assert len(res_2["plots"]) == num_plots
 
+            # Reset cache and force updates cache every second to make sure the farmer gets the most recent data
+            update_interval_before = farmer_api.farmer.update_harvester_cache_interval
+            farmer_api.farmer.update_harvester_cache_interval = 1
+            farmer_api.farmer.harvester_cache = {}
+
             # Test farmer get_harvesters
             async def test_get_harvesters():
+                harvester.plot_manager.trigger_refresh()
+                await time_out_assert(5, harvester.plot_manager.needs_refresh, value=False)
                 farmer_res = await client.get_harvesters()
                 if len(list(farmer_res["harvesters"])) != 1:
+                    log.error(f"test_get_harvesters: invalid harvesters {list(farmer_res['harvesters'])}")
                     return False
                 if len(list(farmer_res["harvesters"][0]["plots"])) != num_plots:
+                    log.error(f"test_get_harvesters: invalid plots {list(farmer_res['harvesters'])}")
                     return False
                 return True
 
-            await time_out_assert(30, test_get_harvesters)
+            await time_out_assert_custom_interval(30, 1, test_get_harvesters)
+
+            # Reset cache and reset update interval to avoid hitting the rate limit
+            farmer_api.farmer.update_harvester_cache_interval = update_interval_before
+            farmer_api.farmer.harvester_cache = {}
 
             expected_result: PlotRefreshResult = PlotRefreshResult()
+            expected_result_matched = True
 
             def test_refresh_callback(refresh_result: PlotRefreshResult):
-                assert refresh_result.loaded_plots == expected_result.loaded_plots
-                assert refresh_result.removed_plots == expected_result.removed_plots
-                assert refresh_result.processed_files == expected_result.processed_files
-                assert refresh_result.remaining_files == expected_result.remaining_files
+                def test_value(name: str, actual: PlotRefreshResult, expected: PlotRefreshResult):
+                    nonlocal expected_result_matched
+                    try:
+                        actual_value = actual.__getattribute__(name)
+                        expected_value = expected.__getattribute__(name)
+                        if actual_value != expected_value:
+                            log.error(f"{name} invalid: actual {actual_value} expected {expected_value}")
+                            expected_result_matched = False
+                    except AttributeError as error:
+                        log.error(f"{error}")
+                        expected_result_matched = False
+
+                test_value("loaded_plots", refresh_result, expected_result)
+                test_value("removed_plots", refresh_result, expected_result)
+                test_value("processed_files", refresh_result, expected_result)
+                test_value("remaining_files", refresh_result, expected_result)
 
             harvester.plot_manager.set_refresh_callback(test_refresh_callback)
 
             async def test_case(
                 trigger, expect_loaded, expect_removed, expect_processed, expected_directories, expect_total_plots
             ):
+                nonlocal expected_result_matched
                 expected_result.loaded_plots = expect_loaded
                 expected_result.removed_plots = expect_removed
                 expected_result.processed_files = expect_processed
                 await trigger
+                expected_result_matched = True
                 harvester.plot_manager.trigger_refresh()
                 assert len(await client_2.get_plot_directories()) == expected_directories
                 await time_out_assert(5, harvester.plot_manager.needs_refresh, value=False)
+                assert expected_result_matched
                 result = await client_2.get_plots()
                 assert len(result["plots"]) == expect_total_plots
                 assert len(harvester.plot_manager.cache) == expect_total_plots
@@ -461,6 +492,24 @@ class TestRpc:
             pool_state = (await client.get_pool_state())["pool_state"]
             assert pool_state[0]["pool_config"]["payout_instructions"] == "1234vy"
 
+            now = time.time()
+            # Big arbitrary numbers used to be unlikely to accidentally collide.
+            before_24h = (now - (25 * 60 * 60), 29984713)
+            since_24h = (now - (23 * 60 * 60), 93049817)
+            for p2_singleton_puzzle_hash, pool_dict in farmer_api.farmer.pool_state.items():
+                for key in ["points_found_24h", "points_acknowledged_24h"]:
+                    pool_dict[key].insert(0, since_24h)
+                    pool_dict[key].insert(0, before_24h)
+
+            sp = farmer_protocol.NewSignagePoint(
+                std_hash(b"1"), std_hash(b"2"), std_hash(b"3"), uint64(1), uint64(1000000), uint8(2)
+            )
+            await farmer_api.new_signage_point(sp)
+            client_pool_state = await client.get_pool_state()
+            for pool_dict in client_pool_state["pool_state"]:
+                for key in ["points_found_24h", "points_acknowledged_24h"]:
+                    assert pool_dict[key][0] == list(since_24h)
+
         finally:
             # Checks that the RPC manages to stop the node
             client.close()
