@@ -1,16 +1,13 @@
-# flake8: noqa: E501
 import asyncio
 import logging
-import os
-import shutil
-from argparse import Namespace
+from pathlib import Path
+from shutil import rmtree
 from typing import Optional, List, Dict
 
 import pytest
-from blspy import G1Element, AugSchemeMPL
+from blspy import G1Element
 
 from salvia.consensus.block_rewards import calculate_base_farmer_reward, calculate_pool_reward
-from salvia.plotting.create_plots import create_plots, PlotKeys
 from salvia.pools.pool_wallet_info import PoolWalletInfo, PoolSingletonState
 from salvia.protocols import full_node_protocol
 from salvia.protocols.full_node_protocol import RespondBlock
@@ -18,16 +15,13 @@ from salvia.rpc.rpc_server import start_rpc_server
 from salvia.rpc.wallet_rpc_api import WalletRpcApi
 from salvia.rpc.wallet_rpc_client import WalletRpcClient
 from salvia.simulator.simulator_protocol import FarmNewBlockProtocol, ReorgProtocol
-from salvia.types.blockchain_format.proof_of_space import ProofOfSpace
 from salvia.types.blockchain_format.sized_bytes import bytes32
 
 from salvia.types.peer_info import PeerInfo
 from salvia.util.bech32m import encode_puzzle_hash
-from tests.block_tools import get_plot_dir, get_plot_tmp_dir
+from tests.block_tools import get_plot_dir
 from salvia.util.config import load_config
-from salvia.util.hash import std_hash
 from salvia.util.ints import uint16, uint32
-from salvia.wallet.derive_keys import master_sk_to_local_sk
 from salvia.wallet.transaction_record import TransactionRecord
 from salvia.wallet.util.wallet_types import WalletType
 from tests.setup_nodes import self_hostname, setup_simulators_and_wallets, bt
@@ -37,6 +31,16 @@ from tests.time_out_assert import time_out_assert
 log = logging.getLogger(__name__)
 
 
+def get_pool_plot_dir():
+    return get_plot_dir() / Path("pool_tests")
+
+
+async def create_pool_plot(p2_singleton_puzzle_hash: bytes32) -> Optional[bytes32]:
+    plot_id = await bt.new_plot(p2_singleton_puzzle_hash, get_pool_plot_dir())
+    await bt.refresh_plots()
+    return plot_id
+
+
 @pytest.fixture(scope="module")
 def event_loop():
     loop = asyncio.get_event_loop()
@@ -51,6 +55,7 @@ class TestPoolWalletRpc:
 
     @pytest.fixture(scope="function")
     async def one_wallet_node_and_rpc(self):
+        rmtree(get_pool_plot_dir(), ignore_errors=True)
         async for nodes in setup_simulators_and_wallets(1, 1, {}):
             full_nodes, wallets = nodes
             full_node_api = full_nodes[0]
@@ -90,6 +95,7 @@ class TestPoolWalletRpc:
 
     @pytest.fixture(scope="function")
     async def setup(self, two_wallet_nodes):
+        rmtree(get_pool_plot_dir(), ignore_errors=True)
         full_nodes, wallets = two_wallet_nodes
         full_node_api = full_nodes[0]
         full_node_server = full_node_api.server
@@ -139,50 +145,6 @@ class TestPoolWalletRpc:
         return num_blocks
         # TODO also return calculated block rewards
 
-    async def create_pool_plot(self, p2_singleton_puzzle_hash: bytes32) -> bytes32:
-        plot_dir = get_plot_dir()
-        temp_dir = get_plot_tmp_dir()
-        args = Namespace()
-        args.size = 22
-        args.num = 1
-        args.buffer = 100
-        args.tmp_dir = temp_dir
-        args.tmp2_dir = plot_dir
-        args.final_dir = plot_dir
-        args.plotid = None
-        args.memo = None
-        args.buckets = 0
-        args.stripe_size = 2000
-        args.num_threads = 0
-        args.nobitfield = False
-        args.exclude_final_dir = False
-        args.list_duplicates = False
-        test_private_keys = [AugSchemeMPL.key_gen(std_hash(b"test_pool_rpc"))]
-        plot_public_key = ProofOfSpace.generate_plot_public_key(
-            master_sk_to_local_sk(test_private_keys[0]).get_g1(), bt.farmer_pk, True
-        )
-        plot_id = ProofOfSpace.calculate_plot_id_ph(p2_singleton_puzzle_hash, plot_public_key)
-        try:
-            plot_keys = PlotKeys(bt.farmer_pk, None, encode_puzzle_hash(p2_singleton_puzzle_hash, "txslv"))
-
-            await create_plots(
-                args,
-                plot_keys,
-                bt.root_path,
-                use_datetime=False,
-                test_private_keys=test_private_keys,
-            )
-        except KeyboardInterrupt:
-            shutil.rmtree(plot_dir, ignore_errors=True)
-            raise
-        await bt.setup_plots()
-        return plot_id
-
-    def delete_plot(self, plot_id: bytes32):
-        for child in get_plot_dir().iterdir():
-            if not child.is_dir() and plot_id.hex() in child.name:
-                os.remove(child)
-
     @pytest.mark.asyncio
     async def test_create_new_pool_wallet_self_farm(self, one_wallet_node_and_rpc):
         client, wallet_node_0, full_node_api = one_wallet_node_and_rpc
@@ -409,7 +371,8 @@ class TestPoolWalletRpc:
         status: PoolWalletInfo = (await client.pw_status(2))[0]
 
         assert status.current.state == PoolSingletonState.SELF_POOLING.value
-        plot_id: bytes32 = await self.create_pool_plot(status.p2_singleton_puzzle_hash)
+        plot_id: Optional[bytes32] = await create_pool_plot(status.p2_singleton_puzzle_hash)
+        assert plot_id is not None
         all_blocks = await full_node_api.get_all_full_blocks()
         blocks = bt.get_consecutive_blocks(
             3,
@@ -477,7 +440,7 @@ class TestPoolWalletRpc:
         with pytest.raises(ValueError):
             await client.pw_absorb_rewards(2)
 
-        self.delete_plot(plot_id)
+        await bt.delete_plot(plot_id)
 
     @pytest.mark.asyncio
     async def test_absorb_pooling(self, one_wallet_node_and_rpc):
@@ -506,7 +469,7 @@ class TestPoolWalletRpc:
 
         log.warning(f"{await wallet_0.get_confirmed_balance()}")
         assert status.current.state == PoolSingletonState.FARMING_TO_POOL.value
-        plot_id: bytes32 = await self.create_pool_plot(status.p2_singleton_puzzle_hash)
+        plot_id: bytes32 = await create_pool_plot(status.p2_singleton_puzzle_hash)
         all_blocks = await full_node_api.get_all_full_blocks()
         blocks = bt.get_consecutive_blocks(
             3,
@@ -557,7 +520,7 @@ class TestPoolWalletRpc:
         bal = await client.get_wallet_balance(2)
         assert bal["confirmed_wallet_balance"] == 0
         log.warning(f"{await wallet_0.get_confirmed_balance()}")
-        self.delete_plot(plot_id)
+        await bt.delete_plot(plot_id)
         assert len(await wallet_node_0.wallet_state_manager.tx_store.get_unconfirmed_for_wallet(2)) == 0
         assert (
             wallet_node_0.wallet_state_manager.get_peak().height == full_node_api.full_node.blockchain.get_peak().height
@@ -731,7 +694,7 @@ class TestPoolWalletRpc:
 
             assert status.current.state == PoolSingletonState.SELF_POOLING.value
             assert status.current.to_json_dict() == {
-                "owner_pubkey": "0xb286bbf7a10fa058d2a2a758921377ef00bb7f8143e1bd40dd195ae918dbef42cfc481140f01b9eae13b430a0c8fe304",
+                "owner_pubkey": "0xb286bbf7a10fa058d2a2a758921377ef00bb7f8143e1bd40dd195ae918dbef42cfc481140f01b9eae13b430a0c8fe304",  # noqa: E501
                 "pool_url": None,
                 "relative_lock_height": 0,
                 "state": 1,
@@ -739,7 +702,7 @@ class TestPoolWalletRpc:
                 "version": 1,
             }
             assert status.target.to_json_dict() == {
-                "owner_pubkey": "0xb286bbf7a10fa058d2a2a758921377ef00bb7f8143e1bd40dd195ae918dbef42cfc481140f01b9eae13b430a0c8fe304",
+                "owner_pubkey": "0xb286bbf7a10fa058d2a2a758921377ef00bb7f8143e1bd40dd195ae918dbef42cfc481140f01b9eae13b430a0c8fe304",  # noqa: E501
                 "pool_url": "https://pool.example.com",
                 "relative_lock_height": 5,
                 "state": 3,
@@ -766,7 +729,6 @@ class TestPoolWalletRpc:
                 return pw_status.current.state == PoolSingletonState.LEAVING_POOL.value
 
             await time_out_assert(timeout=WAIT_SECS, function=status_is_leaving)
-            pw_info: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
 
             async def status_is_self_pooling():
                 # Farm enough blocks to wait for relative_lock_height
@@ -775,7 +737,6 @@ class TestPoolWalletRpc:
                 return pw_status.current.state == PoolSingletonState.SELF_POOLING.value
 
             await time_out_assert(timeout=WAIT_SECS, function=status_is_self_pooling)
-            pw_info: PoolWalletInfo = (await client.pw_status(wallet_id))[0]
             assert len(await wallets[0].wallet_state_manager.tx_store.get_unconfirmed_for_wallet(2)) == 0
 
         finally:
